@@ -1,8 +1,9 @@
 package WWW::MobileCarrierJP;
 use strict;
 use warnings;
+use 5.008001;
 
-our $VERSION = '0.45';
+our $VERSION = '0.46';
 
 1;
 
@@ -24,10 +25,6 @@ This is good wrapper for this problem.
 
 This module makes machine readable format from html :)
 
-=head1 TODO
-
- - softbank flash info
-
 =head1 KNOWLEDGE
 
 =head2 IMAGE
