@@ -13,6 +13,9 @@ sub scrape {
     my $i=1;
     scraper {
         process '//tr[@bgcolor="#cccccc"]/td/table[@cellspacing="1"]/tr[@bgcolor="#ffffff"]/td', 'models[]', ['TEXT', sub {
+            s/^\s+//;
+            s/\s+$//;
+
             if ($i&1) {
                 $model = $_;
             } else {
